@@ -1,7 +1,11 @@
 //! Tactics for Logical AND.
 
+#![allow(unreachable_code)]
+
 use crate::*;
 
+pub use commute as symmetry;
+
 /// `a ∧ b => b ∧ a`.
 pub fn commute<A: Prop, B: Prop>((f0, f1): And<A, B>) -> And<B, A> {
     (f1, f0)
